#!/bin/bash
#
###############################################################
#
# Main script to build LiveCD
# 
# will execute
# - ./customize-livecd.sh
# - ./mini-livecd.sh  (if -mini set)
# - ./linux-live.sl/runme.sh
# - ./restore-system.sh
#
# will take the configuration from
# - ./livecd.conf
#
# Urs Beyerle, PSI
# Modified by Victor Horng for M6 Linux, 2007
#
###############################################################

###############################################################
### Definitions and settings
###############################################################

### for M6 Linux only  ###
SL="-sl"
OS_RELEASE="5"


### source livecd.conf
. livecd.conf

### check if I run inside my directory
if [ ! -x $( basename $0 ) ]; then
    echo "Please run $( basename $0 ) within its directory"
    exit 1
fi

### add extra boot options
BOOT_OPTIONS="$BOOT_OPTIONS $EXTRA_BOOT_OPTIONS"

### define ARCH 
### only i686 for M6 Linux 
ARCH=i686

### write script version to /etc/livecd-release
SCRIPT_VERSION=$( cat version 2>/dev/null )
echo $SCRIPT_VERSION > /etc/livecd-release


###############################################################
### Build LiveCD
###############################################################

### display summary
### -----------------------------------------------------------

echo; echo "--------------------------------------------"

echo "Build of LiveCD started"
echo "Script version:      $SCRIPT_VERSION"
echo "Kernel version:      $KERNEL"
echo "--------------------------------------------"
echo "**** Build for M6 Linux 2007 ****"
echo "--------------------------------------------"



### clean up build script directory
### -----------------------------------------------------------
echo "--------------------------------------------"
echo "Remove all *~ files in $( pwd )"
find . | grep "~$" | while read f; do rm -f "$f"; done
echo "done."
echo "--------------------------------------------"



### Run customize-livecd.sh
### -----------------------------------------------------------
echo
echo "--------------------------------------------"
echo "Run ./customize-livecd.sh "
echo "--------------------------------------------"
./customize-livecd.sh


### Prepare files in linux-live.sl directory 
### -----------------------------------------------------------
echo
echo "--------------------------------------------"
echo "cd linux-live.sl"
echo "--------------------------------------------"

cd linux-live.sl

### create isolinux.cfg from isolinux.cfg.tpl
echo "Create cd-root/isolinux.cfg"
cp cd-root/isolinux.cfg.tpl cd-root/isolinux.cfg

sed -i "s|append linux|append initrd=boot/initrd.gz init=linuxrc $BOOT_OPTIONS|" cd-root/isolinux.cfg
sed -i "s|append failsafe|append initrd=boot/initrd.gz init=linuxrc $BOOT_OPTIONS $FAILSAFE_BOOT_OPTIONS|" cd-root/isolinux.cfg

### create splash.cfg from plash.cfg.tpl
echo "Create in splash.cfg"
cp cd-root/boot/splash.cfg.tpl cd-root/boot/splash.cfg
[ -e /etc/redhat-release ] && RELEASE=$( cat /etc/redhat-release )


### Run runme.sh
### -----------------------------------------------------------
echo
echo "--------------------------------------------"
echo "Run ./runme.sh"
echo "--------------------------------------------"
./runme.sh
rm -f cd-root/boot/splash.cfg
rm -f cd-root/isolinux.cfg

### Run restore-system.sh
### -----------------------------------------------------------
echo
echo "--------------------------------------------"
echo "Now fix things to make this system bootable"
echo "--------------------------------------------"
cd ..
./restore-system.sh 



### End of LiveCD build
### -----------------------------------------------------------
echo "--------------------------------------------"
echo "End of Build LiveCD" 
echo "See /tmp for the ISO image"
echo "--------------------------------------------"
